==> lucide_py-0.1.0-py3-none-any.whl: lucide/icons/sliders_vertical.py <==
from .. import IconBase


class IconSlidersVertical(IconBase):
    class_name = "lucide lucide-sliders-vertical"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "line": {
                "x1": "4",
                "x2": "4",
                "y1": "21",
                "y2": "14"
            }
        },
        {
            "line": {
                "x1": "4",
                "x2": "4",
                "y1": "10",
                "y2": "3"
            }
        },
        {
            "line": {
                "x1": "12",
                "x2": "12",
                "y1": "21",
                "y2": "12"
            }
        },
        {
            "line": {
                "x1": "12",
                "x2": "12",
                "y1": "8",
                "y2": "3"
            }
        },
        {
            "line": {
                "x1": "20",
                "x2": "20",
                "y1": "21",
                "y2": "16"
            }
        },
        {
            "line": {
                "x1": "20",
                "x2": "20",
                "y1": "12",
                "y2": "3"
            }
        },
        {
            "line": {
                "x1": "2",
                "x2": "6",
                "y1": "14",
                "y2": "14"
            }
        },
        {
            "line": {
                "x1": "10",
                "x2": "14",
                "y1": "8",
                "y2": "8"
            }
        },
        {
            "line": {
                "x1": "18",
                "x2": "22",
                "y1": "16",
                "y2": "16"
            }
        }
    ]
}

==> lucide_py-0.1.1-py3-none-any.whl: lucide/icons/sliders_vertical.py <==
from .. import IconBase


class IconSlidersVertical(IconBase):
    class_name = "lucide lucide-sliders-vertical"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "view_box": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "line": {
                "x1": "4",
                "x2": "4",
                "y1": "21",
                "y2": "14"
            }
        },
        {
            "line": {
                "x1": "4",
                "x2": "4",
                "y1": "10",
                "y2": "3"
            }
        },
        {
            "line": {
                "x1": "12",
                "x2": "12",
                "y1": "21",
                "y2": "12"
            }
        },
        {
            "line": {
                "x1": "12",
                "x2": "12",
                "y1": "8",
                "y2": "3"
            }
        },
        {
            "line": {
                "x1": "20",
                "x2": "20",
                "y1": "21",
                "y2": "16"
            }
        },
        {
            "line": {
                "x1": "20",
                "x2": "20",
                "y1": "12",
                "y2": "3"
            }
        },
        {
            "line": {
                "x1": "2",
                "x2": "6",
                "y1": "14",
                "y2": "14"
            }
        },
        {
            "line": {
                "x1": "10",
                "x2": "14",
                "y1": "8",
                "y2": "8"
            }
        },
        {
            "line": {
                "x1": "18",
                "x2": "22",
                "y1": "16",
                "y2": "16"
            }
        }
    ]
}
